@@ -17,7 +17,7 @@
 #include <QFileInfo>
 #include <QHash>
 
-#ifdef QT_DBUS_LIB
+#ifdef HAVE_DBUS
 #include <QDBusConnection>
 #include <QDBusConnectionInterface>
 #endif
@@ -32,7 +32,7 @@
 #include "notifybymacosnotificationcenter.h"
 #elif defined(WITH_SNORETOAST)
 #include "notifybysnore.h"
-#else
+#elif defined(HAVE_DBUS)
 #include "notifybypopup.h"
 #include "notifybyportal.h"
 #endif
@@ -71,7 +71,7 @@ KNotificationManager::KNotificationManager()
     qDeleteAll(d->notifyPlugins);
     d->notifyPlugins.clear();
 
-#ifdef QT_DBUS_LIB
+#ifdef HAVE_DBUS
     if (isInsideSandbox()) {
         QDBusConnectionInterface *interface = QDBusConnection::sessionBus().interface();
         d->portalDBusServiceExists = interface->isServiceRegistered(QStringLiteral("org.freedesktop.portal.Desktop"));
@@ -115,7 +115,7 @@ KNotificationPlugin *KNotificationManager::pluginForAction(const QString &action
         plugin = new NotifyBySnore(this);
 #elif defined(Q_OS_MACOS)
         plugin = new NotifyByMacOSNotificationCenter(this);
-#else
+#elif defined(HAVE_DBUS)
         if (d->portalDBusServiceExists) {
             plugin = new NotifyByPortal(this);
         } else {
@@ -144,11 +144,13 @@ void KNotificationManager::notifyPluginFinished(KNotification *notification)
 
 void KNotificationManager::notificationActivated(int id, const QString &actionId)
 {
-    if (d->notifications.contains(id)) {
+    if (KNotification *n = d->notifications.value(id)) {
         qCDebug(LOG_KNOTIFICATIONS) << id << " " << actionId;
-        KNotification *n = d->notifications[id];
         n->activate(actionId);
+    }
 
+    // we must look up again, as n->activate goes into application code where anything can happen
+    if (KNotification *n = d->notifications.value(id)) {
         // Resident actions delegate control over notification lifetime to the client
         if (!n->hints().value(QStringLiteral("resident")).toBool()) {
             close(id);
